@@ -10,7 +10,7 @@ def blockmanager ( parser, token ):
 		tag_name, block_name = token.split_contents()
 	except ValueError:
 		raise template.TemplateSyntaxError, "%r tag requires a single argument" % token.contents[0]
-	return BlockNode( bar_name )
+	return BlockNode( block_name )
 
 class BlockNode ( template.Node ):
 	def __init__ ( self, block_name ):
